from __future__ import annotations

from typing import AnyStr
from .libjsonc2json import jsonc2json_bin, jsonc2json_str, __version_lib__

__version__ = __version_lib__
__all__ = (
    "__version__",
    "jsonc2json",
    "jsonc2json_bin",
    "jsonc2json_str",
)


def jsonc2json(jsonc: AnyStr) -> AnyStr:
    """Convert JSONC string/bytes to JSON string/bytes

    Args:
        jsonc (AnyStr): JSONC string/bytes

    Returns:
        AnyStr: JSON string/bytes

    Examples:
        >>> jsonc2json('{"foo": "bar"}')
        '{"foo": "bar"}'
        >>> jsonc2json(b'{"foo": "bar"}')
        '{"foo": "bar"}'

    """
    if isinstance(jsonc, bytes):
        return jsonc2json_bin(jsonc)
    return jsonc2json_str(jsonc)



from __future__ import annotations
from typing import List, Optional
import sys
from .libjsonc2json import __version_lib__, jsonc2json_bin


def main(args: Optional[List[str]] = None) -> int:
    argv = args or sys.argv[1:]
    if argv:
        last_arg_lower = argv[-1].lower()
        if last_arg_lower == "-h" or last_arg_lower == "--help":
            sys.stdout.write(
                f"jsonc2json-v{__version_lib__}\nUsage: python -m jsonc2json < input.json(c) > output.json"
            )
            return 0
        if last_arg_lower == "-v" or last_arg_lower == "--version":
            sys.stdout.write(__version_lib__)
            return 0

    stdin_bytes = sys.stdin.buffer.read()
    sys.stdout.buffer.write(jsonc2json_bin(stdin_bytes))
    return 0


if __name__ == "__main__":
    sys.exit(main())



from pathlib import Path
import json
import jsonc2json as jsonc2json
import pytest

PWD = Path(__file__).parent
REPO_ROOT = PWD.parent


def test_version():
    assert jsonc2json.__version__ is not None
    import tomli

    Path("Cargo.toml").read_text()
    cargo_version = tomli.loads(Path("Cargo.toml").read_text())["package"]["version"]
    assert jsonc2json.__version__ == cargo_version
    pyproject_version = tomli.loads(Path("pyproject.toml").read_text())["project"][
        "version"
    ]
    assert jsonc2json.__version__ == pyproject_version


def test_jsonc2json_string():
    data = REPO_ROOT.joinpath("_data", "sample.json").read_text()
    stripped = jsonc2json.jsonc2json(data)

    loaded = json.loads(stripped)
    assert loaded
    assert isinstance(loaded, dict)


def test_jsonc2json_bytes():
    # with open("sample.json", "rb") as f:
    # data = f.read()
    data = REPO_ROOT.joinpath("_data", "sample.json").read_bytes()
    stripped = jsonc2json.jsonc2json_bin(data)
    assert isinstance(stripped, bytes)
    string = stripped.decode("utf-8")
    assert isinstance(string, str)
    loaded = json.loads(stripped)
    assert loaded
    assert isinstance(loaded, dict)


def test_invalid_json():
    jsonstr = "/* foo "
    with pytest.raises(ValueError):
        _stripped = jsonc2json.jsonc2json(jsonstr)
    with pytest.raises(ValueError):
        _stripped = jsonc2json.jsonc2json(jsonstr.encode("utf-8"))


def test_dev():
    pass



from jsonc2json import jsonc2json

jsonc_string = """
{
    "name": /* full */ "John Doe",
    "age": 43,
    "phones": [
        "+44 1234567", // work phone
        "+44 2345678"  // home phone
    ]  # hash comment
}
""".strip()

json_string = jsonc2json(jsonc_string)

print(json_string)
# PRINTS:
# {
#     "name":            "John Doe",
#     "age": 43,
#     "phones": [
#         "+44 1234567",
#         "+44 2345678"
#     ]
# }

assert isinstance(json_string, str)
assert isinstance(jsonc2json(jsonc_string.encode()), bytes)
